@@ -248,3 +248,19 @@ class FlaviusHeaderExtPickup(FlaviusBase):
                                                      create_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_REGIST,
                                                      update_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_REGIST,
                                                      delete_url=conf.FLAVIUS_API_HEADER_EXT_PICKUP_DELETE)
+
+
+class FlaviusPickupLocationFileUpload(FlaviusBase):
+    """
+    Flaviusの受け渡し場所マスタの受取場所画像を登録するAPI
+    """
+    def __init__(self):
+        super(FlaviusPickupLocationFileUpload, self).__init__(search_url='',
+                                                              create_url=conf.FLAVIUS_API_PICKUP_LOCATION_FILE_UPLOAD,
+                                                              update_url='',
+                                                              delete_url='')
+
+    @staticmethod
+    def make_request_headers(content_length=0):
+        return {'Content-Type': 'multipart/form-data',
+                'Content-Length': content_length}
