@@ -104,7 +104,8 @@ class Settings:
 
     @property
     def FLAVIUS_API_PICKUP_LOCATION_FILE_UPLOAD(self):
-        return getattr(settings, "FLAVIUS_API_PICKUP_LOCATION_FILE_UPLOAD", 'api/pickup_location_upload_location_image')
+        return getattr(settings, "FLAVIUS_API_PICKUP_LOCATION_FILE_UPLOAD",
+                       'api/pickup_location_upload_location_image.php')
 
     @property
     def FLAVIUS_API_PICKUP_TIME_LIST(self):
